Coverage for src/tests/test_difference.py: 100%

1 import remedapy as R

2

3

4 class TestDifference:

5 def test_data_first(self):

6 # R.difference(data, other);

7 assert list(R.difference([1, 2, 3, 4], [2, 5, 3])) == [1, 4]

8 assert list(R.difference([1, 1, 2, 2], [1])) == [1, 2, 2]

9

10 def test_data_last(self):

11 # R.difference(other)(data);

12 assert R.pipe([1, 2, 3, 4], R.difference([2, 5, 3]), list) == [1, 4]

13 assert R.pipe([1, 1, 2, 2], R.difference([1]), list) == [1, 2, 2]